@@ -20,6 +20,8 @@ from formant.protos.model.v1 import (
 )
 from typing_extensions import Literal
 
+from formant.sdk.agent.v1.localization.localization_manager import LocalizationManager
+
 from .exceptions import InvalidArgument, handle_agent_exceptions
 from .cancellable_stream_thread import CancellableStreamThread
 
@@ -30,6 +32,7 @@ DEFUALT_IMAGE_CONTENT_TYPE = "image/jpg"  # type: Literal["image/jpg"]
 DEFAULT_SEVERITY_TYPE = "info"  # type: Literal["info"]
 ALLOWED_IMAGE_CONTENT_TYPES = ["image/jpg", "image/jpeg", "image/png"]
 ALLOWED_SEVERITY_TYPES = ["info", "warning", "critical", "error"]
+DEFUALT_LOCALIZATION_STEAM_NAME = "localization"
 
 
 def current_timestamp():
@@ -158,9 +161,20 @@ class Client:
         self._custom_data_channel_message_callback_streams = (
             {}
         )  # type: Dict[Callable[..., None], CancellableStreamThread]
-
+        self._localization_manager_cache = {}  # type: Dict[str,LocalizationManager]
         self._setup_agent_communication()
 
+    def get_localization_manager(
+        self, stream_name=DEFUALT_LOCALIZATION_STEAM_NAME,  # type: str
+    ):
+        # type: (...) -> LocalizationManager
+        validate_type(stream_name, [str])
+        if self._localization_manager_cache.get(stream_name, None) is None:
+            self._localization_manager_cache[stream_name] = LocalizationManager(
+                stream_name, self
+            )
+        return self._localization_manager_cache[stream_name]
+
     # Ingesting telemetry datapoints
 
     @handle_agent_exceptions
@@ -316,9 +330,7 @@ class Client:
             numeric_set.numerics.extend(
                 [
                     math_pb2.NumericSetEntry(
-                        value=v[0],
-                        label=k,
-                        unit=v[1] if v[1] else None,
+                        value=v[0], label=k, unit=v[1] if v[1] else None,
                     )
                 ]
             )
@@ -744,9 +756,7 @@ class Client:
         :param datapoint: A datapoint related to the command
         """
         response = commands_pb2.CommandResponse(
-            request_id=request_id,
-            success=success,
-            datapoint=datapoint,
+            request_id=request_id, success=success, datapoint=datapoint,
         )
         request = agent_pb2.SendCommandResponseRequest(response=response)
         self.agent_stub.SendCommandResponse(request)
@@ -780,8 +790,7 @@ class Client:
         )
 
     def unregister_command_request_callback(
-        self,
-        f,  # type: Callable[[commands_pb2.CommandRequest], None]
+        self, f,  # type: Callable[[commands_pb2.CommandRequest], None]
     ):
         # type: (...) -> None
         """
@@ -847,8 +856,7 @@ class Client:
         return self.agent_stub.GetTeleopInfo(request)
 
     def register_teleop_heartbeat_callback(
-        self,
-        f,  # type: Callable[[agent_pb2.GetTeleopHeartbeatStreamResponse], None]
+        self, f,  # type: Callable[[agent_pb2.GetTeleopHeartbeatStreamResponse], None]
     ):
         # type : (...) -> None
         """
@@ -917,8 +925,7 @@ class Client:
         )
 
     def unregister_custom_data_channel_message_callback(
-        self,
-        f,  # type: Callable[[], None]
+        self, f,  # type: Callable[[], None]
     ):
         # type : (...) -> None
         """
@@ -1293,7 +1300,7 @@ class Client:
         title,  # type: str
         instruction,  # type: str
         labels,  # type: Dict[str, str]
-        hint,  # type:List[intervention_pb2.LabeledPolygon]
+        hint=None,  # type: Optional[List[intervention_pb2.LabeledPolygon]]
         url=None,  # type: str
         content_type=DEFUALT_IMAGE_CONTENT_TYPE,
         # type: Literal["image/jpg", "image/png"]
@@ -1345,8 +1352,9 @@ class Client:
             content_type, ALLOWED_IMAGE_CONTENT_TYPES, "content_type"
         )
         validate_type(labels, [dict])
-        for label in hint:
-            validate_type(label, [intervention_pb2.LabeledPolygon])
+        if hint is not None:
+            for label in hint:
+                validate_type(label, [intervention_pb2.LabeledPolygon])
         for k, v in labels.items():
             validate_type(k, [str])
             validate_type(v, [str])
@@ -1358,7 +1366,8 @@ class Client:
         request.severity = severity_pb
         request.labeling_request.title = title
         request.labeling_request.instruction = instruction
-        request.labeling_request.hint = hint
+        if hint is not None:
+            request.labeling_request.hint.extend(hint)
         request.labeling_request.image.content_type = content_type
         request.labeling_request.image.url = url
         for key, value in labels.items():
@@ -1370,8 +1379,7 @@ class Client:
 
     @handle_agent_exceptions
     def get_intervention_response(
-        self,
-        request_id,  # type: str
+        self, request_id,  # type: str
     ):
         # type : (...) -> agent_pb2.GetInterventionResponse
 
